import React, { forwardRef, useRef } from 'react';
import cn from 'classnames';
import { useFocus } from '@alfalab/hooks';
import mergeRefs from 'react-merge-refs';
import CheckedIcon from '@alfalab/icons-classic/TickXsWhiteIcon';
import IndeterminateIcon from '@alfalab/icons-classic/CheckIndeterminateSWhiteIcon';

var styles = {"component":"checkbox__component_bnahc","box":"checkbox__box_bnahc","disabled":"checkbox__disabled_bnahc","checked":"checkbox__checked_bnahc","indeterminate":"checkbox__indeterminate_bnahc","focused":"checkbox__focused_bnahc","content":"checkbox__content_bnahc","label":"checkbox__label_bnahc","hint":"checkbox__hint_bnahc","indeterminateIcon":"checkbox__indeterminateIcon_bnahc"};
require('./index.css')

const Checkbox = forwardRef(({ checked, label, hint, onChange, className, name, disabled, dataTestId, indeterminate = false, ...restProps }, ref) => {
    const labelRef = useRef(null);
    const [focused] = useFocus(labelRef, 'keyboard');
    const handleChange = (event) => {
        if (onChange) {
            onChange(event, { checked: event.target.checked, name });
        }
    };
    return (
    // eslint-disable-next-line jsx-a11y/label-has-associated-control
    React.createElement("label", { className: cn(styles.component, className, {
            [styles.disabled]: disabled,
            [styles.checked]: checked,
            [styles.indeterminate]: indeterminate,
            [styles.focused]: focused,
        }), ref: mergeRefs([labelRef, ref]) },
        React.createElement("span", { className: styles.box },
            React.createElement("input", Object.assign({ type: 'checkbox', onChange: handleChange, disabled: disabled, checked: checked, "data-test-id": dataTestId }, restProps)),
            checked && React.createElement(CheckedIcon, null),
            indeterminate && !checked && (React.createElement(IndeterminateIcon, { className: styles.indeterminateIcon }))),
        (label || hint) && (React.createElement("span", { className: styles.content },
            label && React.createElement("span", { className: styles.label }, label),
            hint && React.createElement("span", { className: styles.hint }, hint)))));
});
/**
 * Для отображения в сторибуке
 */
Checkbox.defaultProps = {
    indeterminate: false,
};

export { Checkbox };
